@@ -1,46 +1,48 @@
-import os
+import importlib
 import logging
-import pandas as pd
-from typing import Callable, Tuple, Union
-import pyabc
-import numpy as np
-from ..model import MorpheusModel, MorpheusModels
+import os
+import sys
 from numbers import Number
+from typing import Callable, Tuple, Union
+
+import numpy as np
+import pandas as pd
+import pyabc
+
+from ..model import MorpheusModel, MorpheusModels
 
 logger = logging.getLogger("FitMultiCell.PEtab_MS")
-
 try:
     import petab_MS
     import petab_MS.C as C
 except ImportError:
     petab = C = None
-    logger.error("Install petab_MS (see https://github.com/icb-dcm/petab) "
-                 "to use the petab_MS functionality.")
+    logger.error(
+        "Install petab_MS (see https://github.com/icb-dcm/petab) "
+        "to use the petab_MS functionality."
+    )
 
 
 # priors that are evaluated "on-scale"
-SCALED_PRIORS = [C.PARAMETER_SCALE_UNIFORM,
-                 C.PARAMETER_SCALE_NORMAL,
-                 C.PARAMETER_SCALE_LAPLACE]
+SCALED_PRIORS = [
+    C.PARAMETER_SCALE_UNIFORM,
+    C.PARAMETER_SCALE_NORMAL,
+    C.PARAMETER_SCALE_LAPLACE,
+]
 
 
-class PetabImporter():
+class PetabImporter:
     """Import a PEtab model to parameterize it using FitMultiCell pipeline.
     This class provides methods to generate prior, Morpheus, par_maps
     for a pyABC analysis.
-<<<<<<< HEAD
-
-=======
->>>>>>> 0acb391d85cb289fd75d9320e1aaf4bf99d1243f
     Parameters
     ----------
     petab_problem:
         A PEtab problem containing all information on the parameter estimation
         problem.
     """
-    def __init__(
-            self,
-            petab_problem: petab_MS.Problem):
+
+    def __init__(self, petab_problem: petab_MS.Problem):
         self.petab_problem = petab_problem
 
     def create_model(self, executable=None):
@@ -84,7 +86,8 @@ class PetabImporter():
         return get_par_map(parameter_df=self.petab_problem.parameter_df)
 
     def get_nominal_parameters(
-            self, target_scale: str = 'prior') -> pyabc.Parameter:
+        self, target_scale: str = 'prior'
+    ) -> pyabc.Parameter:
         """Get nominal parameters.
         Parameters
         ----------
@@ -107,7 +110,8 @@ class PetabImporter():
         )
 
     def get_bounds(
-            self, target_scale: str = 'prior', use_prior: bool = True) -> dict:
+        self, target_scale: str = 'prior', use_prior: bool = True
+    ) -> dict:
         """Get bounds.
         Parameters
         ----------
@@ -130,7 +134,8 @@ class PetabImporter():
     def get_parameter_names(self, target_scale: str = 'prior'):
         """Get meaningful parameter names, corrected for target scale."""
         parameter_df = petab_MS.normalize_parameter_df(
-            self.petab_problem.parameter_df)
+            self.petab_problem.parameter_df
+        )
 
         # scale
         if target_scale == C.LIN:
@@ -170,23 +175,18 @@ class PetabImporter():
 
         return get_exp_cond_map(condition_df=self.petab_problem.condition_df)
 
-    # def import_petab_problem(self):
-    #     """
-    #     Import model from PEtab problem.
-    #     :return:
-    #         The imported model.
-    #     """
-    #     return import_petab_problem(self.petab_problem)
-
     def _sanity_check(self):
         """Some checks to identify potential problems."""
-        if any(self.scaled_scales[key] != C.LIN
-               and self.prior_scales[key] == C.LIN
-               for key in self.prior_scales):
+        if any(
+            self.scaled_scales[key] != C.LIN
+            and self.prior_scales[key] == C.LIN
+            for key in self.prior_scales
+        ):
             logger.warning(
                 "Found parameters with prior scale lin, parameter scale not "
                 "lin. Note that pyABC currently ignores the parameter scale "
-                "in this case and just performs sampling on the prior scale.")
+                "in this case and just performs sampling on the prior scale."
+            )
 
 
 def create_model(importer, executable):
@@ -212,8 +212,11 @@ def create_model(importer, executable):
     par_map_imported = importer.get_par_map()
     par_scale = importer.petab_problem.get_optimization_parameter_scales()
     if 'observableFormula' in importer.petab_problem.observable_df:
+
         ss_post_process_callable = get_ss_post_process(
-            importer.petab_problem.observable_df)
+            importer.petab_problem.observable_df,
+            os.path.dirname(importer.petab_problem.model_file),
+        )
 
     if cond_status == "no_condition":
         if executable is not None:
@@ -222,13 +225,15 @@ def create_model(importer, executable):
                 par_map=par_map_imported,
                 par_scale=par_scale,
                 ss_post_processing=ss_post_process_callable,
-                executable=executable)
+                executable=executable,
+            )
         else:
             model_con1 = MorpheusModel(
                 importer.petab_problem.model_file,
                 par_map=par_map_imported,
                 par_scale=par_scale,
-                ss_post_processing=ss_post_process_callable)
+                ss_post_processing=ss_post_process_callable,
+            )
         return model_con1
     elif cond_status == "one_condition":
         exp_cond_imported = importer.get_exp_cond_map()
@@ -239,14 +244,16 @@ def create_model(importer, executable):
                 exp_cond_map={'condition1': exp_cond_imported['condition1']},
                 par_scale=par_scale,
                 ss_post_processing=ss_post_process_callable,
-                executable=executable)
+                executable=executable,
+            )
         else:
             model_con1 = MorpheusModel(
                 importer.petab_problem.model_file,
                 par_map=par_map_imported,
                 exp_cond_map={'condition1': exp_cond_imported['condition1']},
                 par_scale=par_scale,
-                ss_post_processing=ss_post_process_callable)
+                ss_post_processing=ss_post_process_callable,
+            )
         return model_con1
     else:
         exp_cond_imported = importer.get_exp_cond_map()
@@ -259,7 +266,8 @@ def create_model(importer, executable):
                     exp_cond_map={cond_key: cond_val},
                     par_scale=par_scale,
                     ss_post_processing=ss_post_process_callable,
-                    executable=executable)
+                    executable=executable,
+                )
         else:
             for cond_key, cond_val in exp_cond_imported.items():
                 tmp_model = MorpheusModel(
@@ -267,22 +275,14 @@ def create_model(importer, executable):
                     par_map=par_map_imported,
                     exp_cond_map={cond_key: cond_val},
                     par_scale=par_scale,
-                    ss_post_processing=ss_post_process_callable)
+                    ss_post_processing=ss_post_process_callable,
+                )
 
             models_list.append(tmp_model)
 
         return MorpheusModels(models_list=models_list)
 
 
-# =======
-#            petab_problem: petab_MS.Problem):
-#        self.petab_problem = petab_problem
-#        self.prior_scales, self.scaled_scales = get_scales(
-#            self.petab_problem.parameter_df)
-#        self._sanity_check()
-# >>>>>>> ece732b (add PEtab support ot FMC)
-
-
 def create_prior(parameter_df: pd.DataFrame) -> pyabc.Distribution:
     """Create prior.
     Note: The prior generates samples according to
@@ -312,39 +312,47 @@ def create_prior(parameter_df: pd.DataFrame) -> pyabc.Distribution:
         #  initialization priors
         prior_type = row[C.OBJECTIVE_PRIOR_TYPE]
         # pars_str = row[C.OBJECTIVE_PRIOR_PARAMETERS]
-        prior_pars = (row.lowerBound, row.upperBound)
-# =======
-#        pars_str = row[C.OBJECTIVE_PRIOR_PARAMETERS]
-#        prior_pars = tuple(float(val) for val in pars_str.split(';'))
-# >>>>>>> ece732b (add PEtab support ot FMC)
-        # create random variable from table entry
-        if prior_type in [C.PARAMETER_SCALE_UNIFORM,
-                          C.UNIFORM]:
+        # prior_pars = (row.lowerBound, row.upperBound)
+        pars_str = row[C.OBJECTIVE_PRIOR_PARAMETERS]
+        prior_pars = tuple(val for val in pars_str.split(';'))
+
+        if prior_pars[0] == 'nan':
+            prior_pars = (row.lowerBound, row.upperBound)
+        if prior_type in [C.PARAMETER_SCALE_UNIFORM, C.UNIFORM]:
             lb, ub = prior_pars
+            lb, ub = float(lb), float(ub)
             # scipy pars are location, width
-            rv = pyabc.RV('uniform', loc=lb, scale=ub-lb)
-        elif prior_type in [C.PARAMETER_SCALE_NORMAL,
-                            C.NORMAL]:
+            rv = pyabc.RV('uniform', loc=lb, scale=ub - lb)
+        elif prior_type in [C.PARAMETER_SCALE_NORMAL, C.NORMAL]:
             mean, std = prior_pars
+            mean, std = float(mean), float(std)
             # scipy pars are mean, std
             rv = pyabc.RV('norm', loc=mean, scale=std)
-        elif prior_type in [C.PARAMETER_SCALE_LAPLACE,
-                            C.LAPLACE]:
+        elif prior_type in [C.PARAMETER_SCALE_LAPLACE, C.LAPLACE]:
             mean, b = prior_pars
+            mean, b = float(mean), float(b)
             # scipy pars are loc=mean, scale=b
             rv = pyabc.RV('laplace', loc=mean, scale=b)
         elif prior_type == C.LOG_NORMAL:
             mean, std = prior_pars
+            mean, std = float(mean), float(std)
             # petab pars are mean, std of the underlying normal distribution
             # scipy pars are s, loc, scale where s = std, scale = exp(mean)
             #  as a simple calculation shows
             rv = pyabc.RV('lognorm', s=std, loc=0, scale=np.exp(mean))
         elif prior_type == C.LOG_LAPLACE:
             mean, b = prior_pars
+            mean, b = float(mean), float(b)
             # petab pars are mean, b of the underlying laplace distribution
             # scipy pars are c, loc, scale where c = 1 / b, scale = exp(mean)
             #  as a simple calculation shows
-            rv = pyabc.RV('loglaplace', c=1/b, scale=np.exp(mean))
+            rv = pyabc.RV('loglaplace', c=1 / b, scale=np.exp(mean))
+        elif prior_type == C.PARAMETER_VALUE_DISCRETE:
+            xk, pk = prior_pars
+            rv = pyabc.RV(
+                "rv_discrete", values=(eval(xk), eval(pk))  # noqa: S307
+            )
+
         else:
             raise ValueError(f"Cannot handle prior type {prior_type}.")
 
@@ -412,32 +420,46 @@ def get_scales(parameter_df: pd.DataFrame) -> Tuple[dict, dict]:
         prior_scales[row[C.PARAMETER_ID]] = (
             row[C.PARAMETER_SCALE]
             if row[C.OBJECTIVE_PRIOR_TYPE] in SCALED_PRIORS
-            else C.LIN)
+            else C.LIN
+        )
         scaled_scales[row[C.PARAMETER_ID]] = row[C.PARAMETER_SCALE]
     return prior_scales, scaled_scales
 
 
-def get_ss_post_process(observable_df: pd.DataFrame) -> Union[Callable, dict]:
+def get_ss_post_process(
+    observable_df: pd.DataFrame, problem_path
+) -> Union[Callable, dict]:
     """Create a callable for the post processing function for observables.
 
     Parameters
     ----------
     observable_df: The PEtab observable data frame.
+    model_file: The model path
     Returns
     -------
     ss_post_process_dict: A Callable or dictionary of callable for each
     summary statistics.
     """
+
     module_path = observable_df.observableFormula.to_dict()
     post_processing_ss_dict = {}
     for key, path in module_path.items():
         head, tail = os.path.split(path)
 
         if head != '':
-            raise ValueError(f"ss_post_process function should be within the "
-                             f"Petab folder. However, now it is on: {head}.")
-        filename, ext = os.path.splitext(tail)
-        new_module = __import__(filename)
+            raise ValueError(
+                f"ss_post_process function should be within the "
+                f"Petab folder. However, now it is on: {head}."
+            )
+        tail_info = tuple(val for val in tail.split(';'))
+        filename, ext = os.path.splitext(tail_info[0])
+        module_path = problem_path + '/' + tail_info[0]
+        module_name = filename
+        spec = importlib.util.spec_from_file_location(module_name, module_path)
+        module = importlib.util.module_from_spec(spec)
+        sys.modules[spec.name] = module
+        spec.loader.exec_module(module)
+        new_module = getattr(module, tail_info[1])
         post_processing_ss_dict[key] = new_module
     return post_processing_ss_dict
 
@@ -488,11 +510,12 @@ def get_ss_post_process(observable_df: pd.DataFrame) -> Union[Callable, dict]:
 
 
 def get_bounds(
-        parameter_df: pd.DataFrame,
-        target_scale: str,
-        prior_scales: dict,
-        scaled_scales: dict,
-        use_prior: bool) -> dict:
+    parameter_df: pd.DataFrame,
+    target_scale: str,
+    prior_scales: dict,
+    scaled_scales: dict,
+    use_prior: bool,
+) -> dict:
     """Get bounds.
     Parameters
     ----------
@@ -542,18 +565,21 @@ def get_bounds(
 
         # convert to target scale
         lower = rescale(
-            lower, origin_scale=origin_scale, target_scale=target_scales[key])
+            lower, origin_scale=origin_scale, target_scale=target_scales[key]
+        )
         upper = rescale(
-            upper, origin_scale=origin_scale, target_scale=target_scales[key])
+            upper, origin_scale=origin_scale, target_scale=target_scales[key]
+        )
         bounds[key] = (lower, upper)
     return bounds
 
 
 def get_nominal_parameters(
-        parameter_df: pd.DataFrame,
-        target_scale: str,
-        prior_scales: dict,
-        scaled_scales: dict) -> pyabc.Parameter:
+    parameter_df: pd.DataFrame,
+    target_scale: str,
+    prior_scales: dict,
+    scaled_scales: dict,
+) -> pyabc.Parameter:
     """Get nominal parameters.
     Parameters
     ----------
@@ -569,8 +595,11 @@ def get_nominal_parameters(
     """
     # unscaled parameters
     par = pyabc.Parameter(
-        {key: parameter_df.loc[key, C.NOMINAL_VALUE]
-         for key in prior_scales.keys()})
+        {
+            key: parameter_df.loc[key, C.NOMINAL_VALUE]
+            for key in prior_scales.keys()
+        }
+    )
 
     # scale
     if target_scale == C.LIN:
@@ -605,8 +634,9 @@ def rescale(val: Number, origin_scale: str, target_scale: str) -> Number:
 
 
 def map_rescale(
-        par: pyabc.Parameter,
-        origin_scales: Union[dict, str], target_scales: Union[dict, str],
+    par: pyabc.Parameter,
+    origin_scales: Union[dict, str],
+    target_scales: Union[dict, str],
 ) -> pyabc.Parameter:
     """Rescale parameter dictionary.
     Parameters
