@@ -137,7 +137,15 @@ class MorpheusModel(ExternalModel):
         self._sanity_chceck_model()
 
     def __str__(self):
-        s = f"MorpheusModel {{\n" f"\tname      : {self.name}\n" f"}}"
+        s = (
+            f"MorpheusModel {{\n"
+            f"\tname      : {self.name}\n"
+            f"\tpar_map      : {self.par_map}\n"
+            f"\tsumstat_funs      : {self.sumstat_funs}\n"
+            f"\texecutable      : {self.eh.executable}\n"
+            f"\toutput_file      : {self.output_file}\n"
+            f"}}"
+        )
         return s
 
     def __repr__(self):
@@ -247,8 +255,6 @@ class MorpheusModel(ExternalModel):
             else:
                 raise KeyError(f"Key {key} is not unique or does not exist.")
 
-        # TODO: better handle the attr for exp_cond_map
-        attr = 'value'
         if self.exp_cond_map:
             if len(self.exp_cond_map) < 2:
                 for condition, val in self.exp_cond_map.items():
@@ -276,6 +282,18 @@ class MorpheusModel(ExternalModel):
 
         tree.write(file_, encoding="utf-8", xml_declaration=True)
 
+    def get_par_value_form_xml_file(self, file_, param):
+        """
+        Get a parameter value from the model's xml file. This is currently
+        being used for testing purposes.
+        """
+        temp_par = copy.deepcopy(param)
+        tree = ET.parse(self.eh.file)  # noqa: S314
+        root = tree.getroot()
+        xpath, attr = self.get_parmap_xpath_attr(temp_par)
+        node = root.findall(xpath)
+        return node[0].attrib[attr]
+
     def compute_sumstats(self, loc):
         """
         Compute summary statistics from the simulated data according to the
@@ -373,8 +391,9 @@ class MorpheusModel(ExternalModel):
         sumstat_pp = {}
         for key, _module in self.ss_post_processing.items():
             try:
-                func = getattr(self.ss_post_processing[key],
-                               function_name, None)
+                func = getattr(
+                    self.ss_post_processing[key], function_name, None
+                )
                 sumstat_pp[key] = func({key: sumstats[key]})
             except Exception as e:
                 raise RuntimeError(
@@ -388,7 +407,8 @@ class MorpheusModel(ExternalModel):
         sumstat_pp = {}
         for key, function in self.ss_post_processing.items():
             try:
-                sumstat_pp[key] = function(sumstats[key])
+                post_process_ss = function({key: sumstats[key]})
+                sumstat_pp[key] = post_process_ss[key]
             except Exception as e:
                 raise RuntimeError(
                     f"the selected ss_post_processing function "
