@@ -7,16 +7,11 @@ multi-celluar systems.
 
 """
 
-from .base import (
-    SumstatFun,
-    IdSumstatFun,
-)
+from .base import IdSumstatFun, SumstatFun
+from .cell_types_cout import CellCountSumstatFun
 from .hexagonal_cluster_sumstat import (
-    ClusterCountSumstatFun,
     CCContributorsAllTpCountSumstatFun,
-)
-from .cell_types_cout import (
-    CellCountSumstatFun,
+    ClusterCountSumstatFun,
 )
 
 __all__ = [
