@@ -1,7 +1,7 @@
 from typing import List
 
-from .base import SumstatFun
 from ..util import tsv_to_df
+from .base import SumstatFun
 
 
 class CellCountSumstatFun(SumstatFun):
@@ -9,12 +9,14 @@ class CellCountSumstatFun(SumstatFun):
     Count the number of different cell types based on a field of interest.
     """
 
-    def __init__(self,
-                 field_of_interest: str,
-                 cell_types_list: List,
-                 time_step: int = None,
-                 time_symbol: str = 't',
-                 name: str = "CellCount"):
+    def __init__(
+        self,
+        field_of_interest: str,
+        cell_types_list: List,
+        time_step: int = None,
+        time_symbol: str = 't',
+        name: str = "CellCount",
+    ):
         """
         Parameters
         ----------
@@ -50,15 +52,21 @@ class CellCountSumstatFun(SumstatFun):
         """
         df = tsv_to_df(loc, "logger.csv")
         return count_cell_types(
-            df, self.field_of_interest, self.cell_types_list,
-            self.time_step, self.time_symbol)
+            df,
+            self.field_of_interest,
+            self.cell_types_list,
+            self.time_step,
+            self.time_symbol,
+        )
 
 
-def count_cell_types(logger_df,
-                     field_of_interest,
-                     cell_types_list,
-                     time_step=None,
-                     time_symbol='t'):
+def count_cell_types(
+    logger_df,
+    field_of_interest,
+    cell_types_list,
+    time_step=None,
+    time_symbol='t',
+):
     """
     Count the number of different cell types based on a field of interest.
     """
@@ -72,9 +80,10 @@ def count_cell_types(logger_df,
     for _ in range(len(cell_types_list)):
         sumstat_dict.append([])
     for j in range(
-            logger_df[time_symbol].unique().tolist()[0],
-            logger_df[time_symbol].unique().tolist()[-1] + 1,
-            time_step):
+        logger_df[time_symbol].unique().tolist()[0],
+        logger_df[time_symbol].unique().tolist()[-1] + 1,
+        time_step,
+    ):
         # takes the next time step
         filtered_data = logger_df[logger_df[time_symbol] == j]
         # time_series_counter = []
@@ -83,8 +92,10 @@ def count_cell_types(logger_df,
         for i, cell_type in enumerate(cell_types_list):
             # count the number of cells with a specific cell type
             sumstat_dict[i].append(
-                filtered_data.groupby(
-                    field_of_interest).size().get(cell_type, 0))
+                filtered_data.groupby(field_of_interest)
+                .size()
+                .get(cell_type, 0)
+            )
         # dict_time_series[j] = pd.DataFrame(
         #     {'cell_type': cell_types_list,
         #      'n_cells': time_series_counter}).set_index('cell_type')
@@ -92,8 +103,12 @@ def count_cell_types(logger_df,
 
 
 def classify_based_on_value(
-        logger_df, field_of_interest, value_of_interest,
-        time_step=None, time_symbol='t'):
+    logger_df,
+    field_of_interest,
+    value_of_interest,
+    time_step=None,
+    time_symbol='t',
+):
     """
     Classify the data of a field of interest based on a value of interest.
 
@@ -131,14 +146,17 @@ def classify_based_on_value(
 
     # loop through the different time steps
     for j in range(
-            logger_df[time_symbol].unique().tolist()[0], df_size * time_step,
-            time_step):
+        logger_df[time_symbol].unique().tolist()[0],
+        df_size * time_step,
+        time_step,
+    ):
         # take the next time step
         filtered_data = logger_df[logger_df[time_symbol] == j]
         # print the RNA concentration
         for _ in range(2):
             series_obj = filtered_data.apply(
-                lambda x: True if x[field_of_interest] >= value_of_interest
+                lambda x: True
+                if x[field_of_interest] >= value_of_interest
                 else False,
                 axis=1,
             )
