@@ -1,9 +1,10 @@
-import numpy as np
 import math
 from typing import List
 
-from .base import SumstatFun
+import numpy as np
+
 from ..util import tsv_to_df
+from .base import SumstatFun
 
 
 class ClusterCountSumstatFun(SumstatFun):
@@ -11,14 +12,15 @@ class ClusterCountSumstatFun(SumstatFun):
     Total number of clusters for all time points.
     """
 
-    def __init__(self,
-                 field_of_interest: str,
-                 cluster_cell_type: List,
-                 time_step: int = None,
-                 time_interval: List = None,
-                 time_symbol: str = 't',
-                 name: str = "ClusterCount",
-                 ):
+    def __init__(
+        self,
+        field_of_interest: str,
+        cluster_cell_type: List,
+        time_step: int = None,
+        time_interval: List = None,
+        time_symbol: str = 't',
+        name: str = "ClusterCount",
+    ):
         """
         Parameters
         ----------
@@ -58,14 +60,23 @@ class ClusterCountSumstatFun(SumstatFun):
         """
         df = tsv_to_df(loc, "logger.csv")
         return get_clusters_count(
-            df, self.field_of_interest, self.cluster_cell_type,
-            self.time_step, self.time_interval, self.time_symbol)
+            df,
+            self.field_of_interest,
+            self.cluster_cell_type,
+            self.time_step,
+            self.time_interval,
+            self.time_symbol,
+        )
 
 
 def get_clusters_count(
-        logger_df, field_of_interest,
-        cluster_cell_type, time_step=None, time_interval=None,
-        time_symbol='t'):
+    logger_df,
+    field_of_interest,
+    cluster_cell_type,
+    time_step=None,
+    time_interval=None,
+    time_symbol='t',
+):
     """
     Get the total number of clusters for all time points.
     """
@@ -100,18 +111,24 @@ def get_clusters_count(
         for index in range(len(morpheus_logger_list)):
             # check if the cell belongs to the cluster and it is not already
             # considered
-            if (morpheus_logger_list[index] in cluster_cell_type) and\
-                    (index not in full_list_of_cluster):
+            if (morpheus_logger_list[index] in cluster_cell_type) and (
+                index not in full_list_of_cluster
+            ):
                 index_list_of_cluster = []
                 # find the neighbor cells list for a specific cell
                 neighbor_cells_list = find_neighbor_list(index, edge)
                 index_list_of_cluster.append(index)
                 # check if the neighbor cells also belong to the same cluster
                 index_list_of_cluster = check_for_connecting_cluster_loop(
-                    cluster_cell_type, edge, neighbor_cells_list,
-                    index_list_of_cluster, morpheus_logger_list)
-                full_list_of_cluster = full_list_of_cluster + \
-                    index_list_of_cluster
+                    cluster_cell_type,
+                    edge,
+                    neighbor_cells_list,
+                    index_list_of_cluster,
+                    morpheus_logger_list,
+                )
+                full_list_of_cluster = (
+                    full_list_of_cluster + index_list_of_cluster
+                )
                 cluster_count = cluster_count + 1
             morpheus_logger_list_unique = sorted(set(morpheus_logger_list))
         if morpheus_logger_list_unique == sorted(cluster_cell_type):
@@ -201,8 +218,10 @@ def find_neighbor_list(cell_id, edge: int, nn=6):
         return "Currently this function can only deal with neighbors = 6!"
     edge_cells_list = find_edge_cell(edge)
     # check if cell_id is out of the range of the hexagonal grid of the model
-    if cell_id < edge_cells_list[0][0] or\
-            cell_id > edge_cells_list[1][edge * 2 - 2]:
+    if (
+        cell_id < edge_cells_list[0][0]
+        or cell_id > edge_cells_list[1][edge * 2 - 2]
+    ):
         print("the cell_id is out of the range")
         return -1
     row = find_row_of_cell(cell_id, edge)
@@ -313,7 +332,8 @@ def find_edge_cell(edge: int):
 
 
 def check_neighbor_inactive_infected_cell(
-        morpheus_neighbor_list, index, inactive_cell, cluster_cell_type):
+    morpheus_neighbor_list, index, inactive_cell, cluster_cell_type
+):
     """
     Check if the cell (index) is infected or not.
 
@@ -333,8 +353,9 @@ def check_neighbor_inactive_infected_cell(
     inactive_cell: int
         The cumulative list of the inactive infected cells.
     """
-    if len(morpheus_neighbor_list) > 0 and \
-            all(elem in cluster_cell_type for elem in morpheus_neighbor_list):
+    if len(morpheus_neighbor_list) > 0 and all(
+        elem in cluster_cell_type for elem in morpheus_neighbor_list
+    ):
         inactive_cell.append(index + 1)
     return inactive_cell
 
@@ -365,8 +386,12 @@ def find_row_of_cell(cell_id: int, edge: int):
 
 
 def check_for_connecting_cluster_loop(
-        cluster_cell_type, edge, neighbor_cells_list,
-        index_list_of_cluster, morpheus_logger_list) -> list:
+    cluster_cell_type,
+    edge,
+    neighbor_cells_list,
+    index_list_of_cluster,
+    morpheus_logger_list,
+) -> list:
     """
     Check whether the neighbor_cell_list ist member of cluster.
 
@@ -395,8 +420,7 @@ def check_for_connecting_cluster_loop(
         if morpheus_logger_list[neighbor_cell] in cluster_cell_type:
             if neighbor_cell not in index_list_of_cluster:
                 index_list_of_cluster.append(neighbor_cell)
-            new_neighbor_cells_list = find_neighbor_list(
-                neighbor_cell, edge)
+            new_neighbor_cells_list = find_neighbor_list(neighbor_cell, edge)
             # check if the cell is still not discovered as part of the
             # cluster in the current iteration
             for cell in new_neighbor_cells_list:
@@ -411,12 +435,13 @@ class ClusterSizeSumstatFun(SumstatFun):
     """
 
     def __init__(
-            self,
-            field_of_interest: str,
-            cluster_cell_type: List,
-            time_point: int,
-            time_symbol: str = 't',
-            name: str = "ClusterSize"):
+        self,
+        field_of_interest: str,
+        cluster_cell_type: List,
+        time_point: int,
+        time_symbol: str = 't',
+        name: str = "ClusterSize",
+    ):
         """
         Parameters
         ----------
@@ -447,13 +472,21 @@ class ClusterSizeSumstatFun(SumstatFun):
         """
         df = tsv_to_df(loc, "logger.csv")
         return get_clusters_sizes_tp(
-            df, self.field_of_interest, self.cluster_cell_type,
-            self.time_point, self.time_symbol)
+            df,
+            self.field_of_interest,
+            self.cluster_cell_type,
+            self.time_point,
+            self.time_symbol,
+        )
 
 
 def get_clusters_sizes_tp(
-        logger_df, field_of_interest, cluster_cell_type,
-        time_point, time_symbol='t'):
+    logger_df,
+    field_of_interest,
+    cluster_cell_type,
+    time_point,
+    time_symbol='t',
+):
     """
     Get the total number of clusters and the size of each cluster
     for a specific time point.
@@ -470,16 +503,21 @@ def get_clusters_sizes_tp(
     for index in range(len(morpheus_logger_list)):
         # check if the cell belongs to the cluster and it is not already
         # considered
-        if (morpheus_logger_list[index] in cluster_cell_type) and\
-                (index + 1 not in full_list_of_cluster):
+        if (morpheus_logger_list[index] in cluster_cell_type) and (
+            index + 1 not in full_list_of_cluster
+        ):
             index_list_of_cluster = []
             # find the neighbor cells list for a specific cell
             neighbor_cells_list = find_neighbor_list(index, edge)
             index_list_of_cluster.append(index)
             # check if the neighbor cells also belong to the same cluster
             index_list_of_cluster = check_for_connecting_cluster_loop(
-                cluster_cell_type, edge, neighbor_cells_list,
-                index_list_of_cluster, morpheus_logger_list)
+                cluster_cell_type,
+                edge,
+                neighbor_cells_list,
+                index_list_of_cluster,
+                morpheus_logger_list,
+            )
             index_list_of_cluster = [x + 1 for x in index_list_of_cluster]
             dict_cluster_member[index + 1] = len(index_list_of_cluster)
             full_list_of_cluster = full_list_of_cluster + index_list_of_cluster
@@ -492,12 +530,13 @@ class CCNonContributorsTpSumstatFun(SumstatFun):
     """
 
     def __init__(
-            self,
-            field_of_interest: str,
-            cluster_cell_type: List,
-            time_point: int,
-            time_symbol: str = 't',
-            name: str = "CCNonContributorsTp"):
+        self,
+        field_of_interest: str,
+        cluster_cell_type: List,
+        time_point: int,
+        time_symbol: str = 't',
+        name: str = "CCNonContributorsTp",
+    ):
         """
         Parameters
         ----------
@@ -528,13 +567,21 @@ class CCNonContributorsTpSumstatFun(SumstatFun):
         """
         df = tsv_to_df(loc, "logger.csv")
         return get_cc_non_contributors_tp(
-            df, self.field_of_interest, self.cluster_cell_type,
-            self.time_point, self.time_symbol)
+            df,
+            self.field_of_interest,
+            self.cluster_cell_type,
+            self.time_point,
+            self.time_symbol,
+        )
 
 
 def get_cc_non_contributors_tp(
-        logger_df, field_of_interest, cluster_cell_type,
-        time_point, time_symbol='t'):
+    logger_df,
+    field_of_interest,
+    cluster_cell_type,
+    time_point,
+    time_symbol='t',
+):
     """
     Get the list of inactive cell in the grid at a specific time point.
     """
@@ -548,8 +595,9 @@ def get_cc_non_contributors_tp(
     full_list_of_cluster = []
     # iterate through all cells in the specified time point
     for index in range(len(morpheus_logger_list)):
-        if (morpheus_logger_list[index] in cluster_cell_type) and \
-                (index + 1 not in full_list_of_cluster):
+        if (morpheus_logger_list[index] in cluster_cell_type) and (
+            index + 1 not in full_list_of_cluster
+        ):
             index_list_of_cluster = []
             neighbor_cells_list = find_neighbor_list(index, edge)
             morpheus_neighbor_list = []
@@ -559,8 +607,11 @@ def get_cc_non_contributors_tp(
             index_list_of_cluster.append(index)
             # check if neighbor cells are CC active or not
             inactive_cell_list = check_neighbor_inactive_infected_cell(
-                morpheus_neighbor_list, index, inactive_cell_list,
-                cluster_cell_type)
+                morpheus_neighbor_list,
+                index,
+                inactive_cell_list,
+                cluster_cell_type,
+            )
     return inactive_cell_list
 
 
@@ -571,13 +622,14 @@ class CCContributorsAllTpCountSumstatFun(SumstatFun):
     """
 
     def __init__(
-            self,
-            field_of_interest: str,
-            cluster_cell_type: List,
-            time_step: int = None,
-            time_interval: List = None,
-            time_symbol: str = 't',
-            name: str = "CCContributorsAllTpCount"):
+        self,
+        field_of_interest: str,
+        cluster_cell_type: List,
+        time_step: int = None,
+        time_interval: List = None,
+        time_symbol: str = 't',
+        name: str = "CCContributorsAllTpCount",
+    ):
         """
         Parameters
         ----------
@@ -615,13 +667,23 @@ class CCContributorsAllTpCountSumstatFun(SumstatFun):
         """
         df = tsv_to_df(loc, "logger.csv")
         return get_count_cc_contributors_alltp(
-            df, self.field_of_interest, self.cluster_cell_type,
-            self.time_step, self.time_interval, self.time_symbol)
+            df,
+            self.field_of_interest,
+            self.cluster_cell_type,
+            self.time_step,
+            self.time_interval,
+            self.time_symbol,
+        )
 
 
 def get_count_cc_contributors_alltp(
-        logger_df, field_of_interest, cluster_cell_type,
-        time_step=None, time_interval=None, time_symbol='t'):
+    logger_df,
+    field_of_interest,
+    cluster_cell_type,
+    time_step=None,
+    time_interval=None,
+    time_symbol='t',
+):
     """
     Get the total number of active infected cells in the grid at a
     specific time point
@@ -652,8 +714,9 @@ def get_count_cc_contributors_alltp(
         full_list_of_cluster = []
         # iterate through all cells in the specified time point
         for index in range(len(morpheus_logger_list)):
-            if (morpheus_logger_list[index] in cluster_cell_type) and \
-                    (index + 1 not in full_list_of_cluster):
+            if (morpheus_logger_list[index] in cluster_cell_type) and (
+                index + 1 not in full_list_of_cluster
+            ):
                 index_list_of_cluster = []
                 # find the neighbor cells list for a specific cell
                 neighbor_cells_list = find_neighbor_list(index, edge)
@@ -664,11 +727,14 @@ def get_count_cc_contributors_alltp(
                 index_list_of_cluster.append(index)
                 # check if neighbor cells are CC active or not
                 inactive_cell_list = check_neighbor_inactive_infected_cell(
-                    morpheus_neighbor_list, index, inactive_cell_list,
-                    cluster_cell_type)
+                    morpheus_neighbor_list,
+                    index,
+                    inactive_cell_list,
+                    cluster_cell_type,
+                )
                 # find CC active cells
         active_cell_count = sum(
-            i in cluster_cell_type for i in morpheus_logger_list)\
-            - len(list(set(inactive_cell_list)))
+            i in cluster_cell_type for i in morpheus_logger_list
+        ) - len(list(set(inactive_cell_list)))
         count_per_time_point[j] = active_cell_count
     return {"cc_contributors": list(count_per_time_point.values())}
