@@ -3,8 +3,12 @@ import numpy as np
 
 
 def plot_different_cell_type(
-        dict_time_series, cell_types_list, time_step=1, figure_title='',
-        cell_types_names=None):
+    dict_time_series,
+    cell_types_list,
+    time_step=1,
+    figure_title='',
+    cell_types_names=None,
+):
     """
     plot 1d chart of the count of cell types at different time points
 
@@ -105,7 +109,8 @@ def plot_cluster_size_time_point(dict_time_series, figure_title=''):
 
 
 def plot_cluster_count_all_time_point(
-        dict_time_series, time_step=1, figure_title=''):
+    dict_time_series, time_step=1, figure_title=''
+):
     """
     plot a bar chart of the counts of clusters at multiple time points
 
@@ -143,7 +148,8 @@ def plot_cluster_count_all_time_point(
 
 
 def plot_cluster_size_all_time_point(
-        dict_time_series, time_step=1, figure_title=''):
+    dict_time_series, time_step=1, figure_title=''
+):
     """
     plot a bar chart of the size of clusters at multiple time points
 
@@ -182,7 +188,8 @@ def plot_cluster_size_all_time_point(
 
 
 def plot_active_cell_all_time_point(
-        dict_time_series, time_step=1, figure_title=''):
+    dict_time_series, time_step=1, figure_title=''
+):
     """
     plot a bar chart of the number of active infected cell at multiple time
     points
